@@ -2,5 +2,5 @@
 ;;; For more information see (info "(emacs) Directory Variables")
 
 ((rustic-mode . ((eglot-workspace-configuration
-                  . (:rust-analyzer (:cargo (:features ["lyric-finder" "image" "notify"])
+                  . (:rust-analyzer (:cargo (:features ["image" "notify"])
                                      :check (:command "clippy")))))))
