@@ -58,6 +58,12 @@ pub enum IdOrName {
     Name(String),
 }
 
+#[derive(Debug, Serialize, Deserialize, clap::ValueEnum, Clone, Copy)]
+pub enum EditAction {
+    Add,
+    Delete,
+}
+
 #[derive(Debug, Serialize, Deserialize)]
 pub enum PlaylistCommand {
     New {
@@ -82,6 +88,12 @@ pub enum PlaylistCommand {
         id: Option<PlaylistId<'static>>,
         delete: bool,
     },
+    Edit {
+        action: EditAction,
+        playlist_id: PlaylistId<'static>,
+        track_id: Option<TrackId<'static>>,
+        album_id: Option<AlbumId<'static>>,
+    },
 }
 
 #[derive(Debug, Serialize, Deserialize)]
